// src/index.ts
var icons = {
  success: '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" stroke="currentColor" stroke-width="1.5" fill="none" stroke-linecap="round" stroke-linejoin="round"><path stroke="none" d="M0 0h24v24H0z"/><circle cx="12" cy="12" r="9" /><path d="M9 12l2 2l4 -4" /></svg>',
  warning: '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" stroke="currentColor" stroke-width="1.5" fill="none" stroke-linecap="round" stroke-linejoin="round"><path stroke="none" d="M0 0h24v24H0z"/><circle cx="12" cy="12" r="9" /><line x1="12" y1="8" x2="12" y2="12" /><line x1="12" y1="16" x2="12.01" y2="16" /></svg>',
  danger: '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" stroke="currentColor" stroke-width="1.5" fill="none" stroke-linecap="round" stroke-linejoin="round"><path stroke="none" d="M0 0h24v24H0z"/><path d="M12 9v2m0 4v.01" /><path d="M5.07 19H19a2 2 0 0 0 1.75 -2.75L13.75 4a2 2 0 0 0 -3.5 0L3.25 16.25a2 2 0 0 0 1.75 2.75" /></svg>',
  info: '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" stroke="currentColor" stroke-width="1.5" fill="none" stroke-linecap="round" stroke-linejoin="round" class="feather feather-info"><circle cx="12" cy="12" r="10"></circle><line x1="12" y1="16" x2="12" y2="12"></line><line x1="12" y1="8" x2="12.01" y2="8"></line></svg>'
};
var TRANSITION_DURATION = 400;
var getOptions = (element) => {
  const options = {
    type: element.getAttribute("data-notify-type") || "success",
    position: element.getAttribute("data-notify-position") || "top-right",
    duration: element.getAttribute("data-notify-duration") || 3e3,
    transition: element.getAttribute("data-notify-transition") || "fade"
  };
  return options;
};
var Notify = (options, callback) => {
  let notify = document.querySelector("[data-notify]");
  if (!notify) {
    notify = document.querySelector("#notify");
    if (notify) {
      notify.setAttribute("data-notify", "");
      console.warn(
        "buzz-notify: The old version of buzz-notify is deprecated. Please visit the new version at https://github.com/eliutdev/buzz-notify"
      );
    }
  }
  if (!notify) {
    throw new Error("No notification element found");
  }
  const NotifyEvent = new CustomEvent("notifyclose");
  const { title, html, type, position, duration, transition, config } = { ...getOptions(notify), ...options };
  const _duration = Number(duration);
  if (!["top-left", "top-center", "top-right", "bottom-left", "bottom-center", "bottom-right"].includes(position)) {
    throw new Error("Position is not valid");
  }
  if (!notify.querySelector(`[data-notify-wrapper-position='${position}']`)) {
    const notifyWrapper2 = document.createElement("div");
    notifyWrapper2.setAttribute("data-notify-wrapper-position", position);
    notify.appendChild(notifyWrapper2);
  }
  const notifyWrapper = notify.querySelector(`[data-notify-wrapper-position='${position}']`);
  const notifyContent = document.createElement("div");
  notifyContent.setAttribute("class", `notify notify--${type}`);
  notifyContent.setAttribute("role", "alert");
  notifyContent.setAttribute("aria-live", "assertive");
  notifyContent.setAttribute("aria-atomic", "true");
  notifyContent.classList.add(`${transition}-active`);
  setTimeout(() => {
    notifyContent.classList.remove(`${transition}-active`);
  }, TRANSITION_DURATION);
  let content = '<div class="notify__content">';
  content += `<div class="notify__title">${title}</div>`;
  if (html) {
    content += `${html}`;
  }
  content += "</div>";
  notifyContent.innerHTML = content;
  const _icons = { ...icons, ...config?.icons };
  notifyContent.insertAdjacentHTML(
    "afterbegin",
    `<span class="notify__icon" style="color: var(--bzn-color-${type})">${_icons[type]}</span>`
  );
  const [vertical] = position.split("-");
  if (vertical === "top") {
    notifyWrapper.insertAdjacentElement("afterbegin", notifyContent);
  }
  if (vertical === "bottom") {
    notifyWrapper.insertAdjacentElement("beforeend", notifyContent);
  }
  if (_duration * 1 > 0) {
    setTimeout(
      () => {
        notifyContent.classList.add(`${transition}-leave`);
      },
      _duration - TRANSITION_DURATION / 2
    );
    setTimeout(() => {
      if (typeof callback === "function") {
        callback();
      }
      notifyContent.dispatchEvent(NotifyEvent);
      notifyContent.remove();
    }, _duration);
  }
  notifyContent.addEventListener("click", () => {
    notifyContent.classList.add(`${transition}-leave`);
    setTimeout(() => {
      notifyContent.remove();
      notifyContent.dispatchEvent(NotifyEvent);
    }, TRANSITION_DURATION / 2);
  });
  return notifyContent;
};
var NotifyAsync = (options) => {
  const notifyContent = Notify(options);
  return new Promise((resolve) => {
    const timer = setTimeout(resolve, options?.duration || 3e3);
    notifyContent.addEventListener("notifyclose", () => {
      resolve();
      clearTimeout(timer);
    });
  });
};
export {
  Notify,
  NotifyAsync
};
